dm: treewide: Rename ..._platdata variables to just ..._plat

Try to maintain some consistency between these variables by using _plat as
a suffix for them.

Signed-off-by: Simon Glass <sjg@chromium.org>
diff --git a/include/dm/platform_data/serial_coldfire.h b/include/dm/platform_data/serial_coldfire.h
index ba916fe..5e265e9 100644
--- a/include/dm/platform_data/serial_coldfire.h
+++ b/include/dm/platform_data/serial_coldfire.h
@@ -7,13 +7,13 @@
 #define __serial_coldfire_h
 
 /*
  * struct coldfire_serial_platdata - information about a coldfire port
  *
  * @base:               Uart port base register address
  * @port:               Uart port index, for cpu with pinmux for uart / gpio
  * baudrtatre:          Uart port baudrate
  */
-struct coldfire_serial_platdata {
+struct coldfire_serial_plat {
 	unsigned long base;
 	int port;
 	int baudrate;
@@ -7,13 +7,13 @@
 
 /*
- * struct coldfire_serial_platdata - information about a coldfire port
+ * struct coldfire_serial_plat - information about a coldfire port
  *
  * @base:               Uart port base register address